using System;
using System.Collections.Generic;
using System.ServiceModel;
using Microsoft.AspNetCore.Builder;
using Microsoft.AspNetCore.Hosting;
using Microsoft.AspNetCore.Http;
using Microsoft.AspNetCore.Http.Features;
using Microsoft.AspNetCore.Rewrite;
using Microsoft.AspNetCore.StaticFiles;
using Microsoft.Extensions.Configuration;
using Microsoft.Extensions.DependencyInjection;
using Microsoft.Extensions.FileProviders;
using Microsoft.Extensions.Hosting;
using MySystem.PublicClass.GraphQL;
using System.Text;
using Microsoft.IdentityModel.Tokens;
using System.Linq;
using Microsoft.AspNetCore.Server.Kestrel.Core;

namespace MySystem
{
    public class Startup
    {
        public Startup(IConfiguration configuration)
        {
            Configuration = configuration;

        }

        public IConfiguration Configuration { get; }

        // This method gets called by the runtime. Use this method to add services to the container.
        public void ConfigureServices(IServiceCollection services)
        {
            services.AddControllersWithViews();
            services.AddRouting(options =>
            {
                options.LowercaseUrls = true;
            });
            services.AddSingleton<IHttpContextAccessor, HttpContextAccessor>();
            services.Configure<Setting>(Configuration.GetSection("Setting"));
            services.Configure<KestrelServerOptions>(options =>
            {
                options.AllowSynchronousIO = true;
            });
            services.Configure<IISServerOptions>(options =>
            {
                options.AllowSynchronousIO = true;
            });
            // 测试后必须注释
            // services.AddCors(option => option.AddPolicy("cors", policy => policy.AllowAnyHeader().AllowAnyMethod().AllowCredentials().SetIsOriginAllowed(_ => true)));            
            // 测试后必须注释
            services.Configure<KestrelServerOptions>(x => x.AllowSynchronousIO = true).Configure<IISServerOptions>(x => x.AllowSynchronousIO = true);
            services.AddMvc(options =>
            {
                options.EnableEndpointRouting = false;
                options.Filters.Add(typeof(GlobalExceptions));
            });
            services.AddSession(options =>
            {
                // 设置 Session 过期时间
                options.IdleTimeout = TimeSpan.FromHours(1);
                options.Cookie.HttpOnly = true;
            });
            services.AddSingleton<IRepository, Repository>();
            services.Configure<FormOptions>(x =>
            {
                x.MultipartBodyLengthLimit = 50 * 1024 * 1024;//不到300M
            });
            //生成密钥
            var symmetricKeyAsBase64 = Configuration["Setting:JwtSecret"];
            var keyByteArray = Encoding.ASCII.GetBytes(symmetricKeyAsBase64);
            var signingKey = new SymmetricSecurityKey(keyByteArray);
            //认证参数
            services.AddAuthentication("Bearer").AddJwtBearer(o =>
            {
                o.TokenValidationParameters = new TokenValidationParameters
                {
                    ValidateIssuerSigningKey = true,//是否验证签名,不验证的画可以篡改数据，不安全
                    IssuerSigningKey = signingKey,//解密的密钥
                    ValidateIssuer = true,//是否验证发行人，就是验证载荷中的Iss是否对应ValidIssuer参数
                    // ValidIssuer = Configuration["Setting:JwtIss"],//发行人
                    IssuerValidator = (m, n, z) =>
                    {
                        return n.Issuer;
                    },
                    ValidateAudience = true,//是否验证订阅人，就是验证载荷中的Aud是否对应ValidAudience参数
                    // ValidAudience = Configuration["Setting:JwtAud"],//订阅人
                    AudienceValidator = (m, n, z) =>
                    {
                        string check = RedisDbconn.Instance.Get<string>("utoken:" + n.Issuer);
                        return m != null && m.FirstOrDefault().Equals(check);
                    },
                    ValidateLifetime = true,//是否验证过期时间，过期了就拒绝访问
                    ClockSkew = TimeSpan.Zero,//这个是缓冲过期时间，也就是说，即使我们配置了过期时间，这里也要考虑进去，过期时间+缓冲，默认好像是7分钟，你可以直接设置为0
                    RequireExpirationTime = true,
                };
            });
            // services.AddHostedService<PublicService>();
            // services.AddHostedService<PublicErrService>();

            //services.AddHttpContextAccessor();

            string appkey = Configuration["Setting:AppKey"];
            string appid = Configuration["Setting:AppId"];
            string checkurl = Configuration["Setting:CheckUrl"];
            string serviceurl = Configuration["Setting:WebServiceUrl"];
            string schemeurl = Configuration["Setting:DbSchemeUrl"];
            MySystemLib.SystemPublicFuction.appkey = appkey;
            MySystemLib.SystemPublicFuction.appid = appid;
            MySystemLib.SystemPublicFuction.checkurl = checkurl;
            MySystemLib.SystemPublicFuction.appcheck = "success";
            // var binding = new BasicHttpBinding();
            // binding.MaxReceivedMessageSize = 2147483647;
            // var endpoint = new EndpointAddress(Configuration["Setting:WebServiceUrl"]);
            // var factory = new ChannelFactory<GetDataBaseSoap>(binding, endpoint);
            // var callClient = factory.CreateChannel();
            // DataBaseRequestBody body = new DataBaseRequestBody();
            // body.appid = appid;
            // body.appkey = appkey;
            // var request = new DataBaseRequest(body);
            // var wait = callClient.DataBaseAsync(request);
            // wait.Wait();
            // tempuri.org.CustomerTables[] servicetable = wait.Result.Body.DataBaseResult;
            // Dictionary<string, Dictionary<string, string>> tables = new Dictionary<string, Dictionary<string, string>>();
            // foreach (tempuri.org.CustomerTables subtable in servicetable)
            // {
            //     Dictionary<string, string> Columns = new Dictionary<string, string>();
            //     foreach (tempuri.org.CustomerColumns subcolumn in subtable.Columns)
            //     {
            //         Columns.Add(subcolumn.FieldName, subcolumn.FieldType);
            //     }
            //     tables.Add(subtable.TableName, Columns);
            // }
            // servicetable = null;
            // string database = Library.function.GetWebRequest(serviceurl + "?appid=" + appid + "&appkey=" + appkey);
            // Dictionary<string, Dictionary<string, string>> tables = Newtonsoft.Json.JsonConvert.DeserializeObject<Dictionary<string, Dictionary<string, string>>>(database);
            // MySystemLib.SystemPublicFuction.dbtables = tables;

            // string schemeString = Library.function.GetWebRequest(schemeurl + "?appid=" + appid + "&appkey=" + appkey);
            // RedisDbconn.Instance.Set("dbscheme", Newtonsoft.Json.JsonConvert.DeserializeObject<List<MySystem.DbScheme>>(schemeString));
            string conn = Configuration["Setting:SqlConnStr"];
            Dictionary<string, Dictionary<string, string>> tables = new Dictionary<string, Dictionary<string, string>>();
            System.Data.DataTable tablecollection = Library.CustomerSqlConn.dtable("select DISTINCT TABLE_NAME from information_schema.columns where table_schema = 'KxsSpServer'", conn);
            foreach (System.Data.DataRow subtable in tablecollection.Rows)
            {
                Dictionary<string, string> Columns = new Dictionary<string, string>();
                System.Data.DataTable columncollection = Library.CustomerSqlConn.dtable("select COLUMN_NAME,DATA_TYPE from information_schema.columns where table_schema = 'KxsSpServer' and TABLE_NAME='" + subtable["TABLE_NAME"].ToString() + "'", conn);
                foreach (System.Data.DataRow column in columncollection.Rows)
                {
                    string datatype = column["DATA_TYPE"].ToString();
                    if (datatype == "decimal")
                    {
                        datatype = "numeric";
                    }
                    Columns.Add(column["COLUMN_NAME"].ToString(), datatype);
                }
                tables.Add(subtable["TABLE_NAME"].ToString(), Columns);
            }
            MySystemLib.SystemPublicFuction.dbtables = tables;

            RedisDbconn.csredis = new CSRedis.CSRedisClient(Configuration["Setting:RedisConnStr"]);
        }

        // This method gets called by the runtime. Use this method to configure the HTTP request pipeline.
        public void Configure(IApplicationBuilder app, IWebHostEnvironment env)
        {
            if (env.IsDevelopment())
            {
                app.UseDeveloperExceptionPage();
                // app.UseExceptionHandler("/Home/Error");
            }
            else
            {
                app.UseExceptionHandler("/Home/Error");
                app.UseHsts();
            }
            Library.ConfigurationManager.EnvironmentFlag = 2;
            Library.function.WritePage("/", "WebRootPath.txt", env.WebRootPath);
            // app.UseStatusCodePagesWithReExecute("/public/errpage/pc/{0}.html");

            // RequestDelegate handler = async context =>
            // {
            //     var response = context.Response;
            //     if (response.StatusCode < 500)
            //     {
            //         response.("/public/errpage/pc/{0}.html");
            //     }
            // };
            // app.UseStatusCodePages(builder => builder.Run(handler));
            app.UseStaticFiles();
            // app.UseStaticFiles(new StaticFileOptions
            // {
            //     FileProvider = new PhysicalFileProvider(AppContext.BaseDirectory + "/static"),
            //     RequestPath = "/static"
            // });
            // app.UseStaticFiles(new StaticFileOptions
            // {
            //     FileProvider = new PhysicalFileProvider(AppContext.BaseDirectory + "/" + Configuration["Setting:Database"]),
            //     RequestPath = "/" + Configuration["Setting:Database"]
            // });
            app.UseStaticFiles(new StaticFileOptions
            {
                ContentTypeProvider = new FileExtensionContentTypeProvider(new Dictionary<string, string>
                {
                      { ".apk", "application/vnd.android.package-archive" }
                })
            });

            app.UseCors("cors");
            app.UseAuthentication();
            app.UseRouting();
            app.UseAuthorization();
            app.UseSession();

            app.UseEndpoints(endpoints =>
            {
                endpoints.MapControllerRoute(
                    name: "default",
                    pattern: "{controller=Home}/{action=Index}/{Id?}");
            });

            // 必须执行
            GetSpTimer.Instance.Start(); //定时从redis抓取第三方接收数据
            SpNoticeHelper.Instance.Start();
            LogHelper.Instance.Start();
            CheckWifiData.Instance.Start(); //解析wifi设备通知数据
            // 必须执行
        }
    }
}